==> plantuml-libs-5.2.0.tgz: package/distribution/azure-4/Item/General/ServiceImage.md <==
# ServiceImage


```text
azure-4/Item/General/ServiceImage
```

```text
include('azure-4/Item/General/ServiceImage')
```



| Illustration | ServiceImage | ServiceImageCard | ServiceImageGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/General/ServiceImage.png) | ![illustration for ServiceImage](../../../azure-4/Item/General/ServiceImage.Local.png) | ![illustration for ServiceImageCard](../../../azure-4/Item/General/ServiceImageCard.Local.png) | ![illustration for ServiceImageGroup](../../../azure-4/Item/General/ServiceImageGroup.Local.png) |




## ServiceImage

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceImage
include('azure-4/Item/General/ServiceImage')

' renders the element
ServiceImage('ServiceImage', 'Service Image', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceImage
include('azure-4/Item/General/ServiceImage')

' renders the element
ServiceImage('ServiceImage', 'Service Image', 'an optional tech label')
@enduml
```

## ServiceImageCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceImageCard
include('azure-4/Item/General/ServiceImage')

' renders the element
ServiceImageCard('ServiceImageCard', 'Service Image Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceImageCard
include('azure-4/Item/General/ServiceImage')

' renders the element
ServiceImageCard('ServiceImageCard', 'Service Image Card', 'an optional description')
@enduml
```

## ServiceImageGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceImageGroup
include('azure-4/Item/General/ServiceImage')

' renders the element
ServiceImageGroup('ServiceImageGroup', 'Service Image Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceImageGroup
include('azure-4/Item/General/ServiceImage')

' renders the element
ServiceImageGroup('ServiceImageGroup', 'Service Image Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/azure-4/Item/General/ServiceImage.md <==
# ServiceImage


```text
azure-4/Item/General/ServiceImage
```

```text
include('azure-4/Item/General/ServiceImage')
```



| Illustration | ServiceImage | ServiceImageCard | ServiceImageGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/General/ServiceImage.png) | ![illustration for ServiceImage](../../../azure-4/Item/General/ServiceImage.Local.png) | ![illustration for ServiceImageCard](../../../azure-4/Item/General/ServiceImageCard.Local.png) | ![illustration for ServiceImageGroup](../../../azure-4/Item/General/ServiceImageGroup.Local.png) |




## ServiceImage

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceImage
include('azure-4/Item/General/ServiceImage')

' renders the element
ServiceImage('ServiceImage', 'Service Image', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceImage
include('azure-4/Item/General/ServiceImage')

' renders the element
ServiceImage('ServiceImage', 'Service Image', 'an optional tech label')
@enduml
```

## ServiceImageCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceImageCard
include('azure-4/Item/General/ServiceImage')

' renders the element
ServiceImageCard('ServiceImageCard', 'Service Image Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceImageCard
include('azure-4/Item/General/ServiceImage')

' renders the element
ServiceImageCard('ServiceImageCard', 'Service Image Card', 'an optional description')
@enduml
```

## ServiceImageGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceImageGroup
include('azure-4/Item/General/ServiceImage')

' renders the element
ServiceImageGroup('ServiceImageGroup', 'Service Image Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceImageGroup
include('azure-4/Item/General/ServiceImage')

' renders the element
ServiceImageGroup('ServiceImageGroup', 'Service Image Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
